"""
Utility functions for handling prolific apis

"""
import pandas as pd
import requests
import json
import pandas

class ProlificStudy(object):
    def __init__(self, token, study_id):
        self.headers = {
            'Authorization': f'Token {token}',
        }
        self.study_id = study_id
        self.users = {'completed':set(), 'returned':set(), 'timeout':set(), 'inprogress':set()}
        self.study_status = None


    def list_all_studies(self):
        url = 'https://api.prolific.com/api/v1/studies/'
        response = requests.get(url, headers=self.headers)
        if response.status_code == 200:
            data = response.json()  # If the response contains JSON data
            studies = pd.DataFrame.from_records(data['results'])
            print('You currently have %s studies'%len(data['results']))
            print(studies[['id','name','study_type','internal_name','status']].to_records())
        else:
            print(f"Error: {response.status_code} - {response.text}")

    def get_study_by_id(self, study_id):
        url = f'https://api.prolific.com/api/v1/studies/{study_id}/'
        response = requests.get(url, headers=self.headers)
        if response.status_code == 200:
            data = response.json()  # If the response contains JSON data
            return data
        else:
            print(f"Error: {response.status_code} - {response.text}")

    #get all submissions, might be super slow when you have a long list of submissions
    def get_submissions(self):
        url = 'https://api.prolific.com/api/v1/submissions/'
        response = requests.get(url, headers=self.headers)
        if response.status_code == 200:
            data = response.json()  # If the response contains JSON data
            print('You currently have %s submissions'%len(data['results']))
            return data['results']
        else:
            print(f"Error: {response.status_code} - {response.text}")

    # get the list of submissions from a study
    def get_submissions_from_study(self, study_id = None):
        if study_id == None:
            study_id = self.study_id
        api_endpoint = 'https://api.prolific.com/api/v1/submissions?study={}'
        url = api_endpoint.format(study_id)
        response = requests.get(url, headers=self.headers)
        data = response.json()['results']
        #print(len(data))
        #print(data.keys())
        return data

    # get the list of submissions from a study
    def get_recent_study_submissions(self, study_id):
        url = f'https://api.prolific.com/api/v1/studies/{study_id}/submissions/'
        response = requests.get(url, headers=self.headers)
        if response.status_code == 200:
            data = response.json()  # If the response contains JSON data
            print('You currently have %s submissions' % len(data['results']))
            return (data['results'])
        else:
            print(f"Error: {response.status_code} - {response.text}")

    # get the status of a specific submission
    def get_submission_from_id(self, submission_id):
        url = f'https://api.prolific.com/api/v1/submissions/{submission_id}/'
        response = requests.get(url, headers=self.headers)
        if response.status_code == 200:
            data = response.json()  # If the response contains JSON data
            return data
        else:
            print(f"Error: {response.status_code} - {response.text}")




prolific = ProlificStudy(token = 'yRB91_ngkHclqd36bhXCGWwl5fqU4iVlXX-2i61cfNoh7Tpvh4tH8R6IAxEBsYrkMnyc4X8tEpmmJhHXiHiRkFZYIm_Jr-pCoXFqyrIHX30qUuT5RMcIc7rG',
                         study_id='6500644505e4c811e95fb6de')
prolific.list_all_studies()
#prolific.get_study_by_id('651d90aa31f42a08bce57feb')
#prolific.get_recent_study_submissions('651d90aa31f42a08bce57feb')
#print(prolific.get_submission_from_id('651db6a7718107d07e95639d'))
print(len(prolific.get_submissions_from_study()))